CHANGES
=======

0.2 (2018-06-11)
----------------

- Fix list of allowed verbs for failed (unauthorized) preflight (see `PR #4`_).

.. _PR #4: https://github.com/morepath/more.cors/pull/4


0.1 (2018-06-08)
----------------

- Initial public release
